==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/hu.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Hivatkozás:",
    "Password:" : "Jelszó:",
    "Generating system report failed." : "Hiba a rendszer jelentés készítése közben.",
    "Subscription notifications" : "Előfizetési értesítések",
    "Could not create folder \"System information\" to store generated report." : "Nem lehet \"Rendszer információ\" könyvtárat létre hozni a jelentések készítéséhez.",
    "Could not create file \"%s\" to store generated report." : "Nem lehet létrehozni a \"%s\" fájlt az előállított riport tárolásához.",
    "Could not share file \"%s\"." : "Nem lehet megosztani a \"%s\" fájlt.",
    "Nextcloud Subscription" : "Nextcloud előfizetés",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "A szerverének nincs Nextcloud előfizetése vagy az előfizetés lejárt.",
    "Your Nextcloud server subscription does not cover your number of users." : "A Nextcloud szerver előfizetése nem fedezi a felhasználói számát.",
    "Your Nextcloud Subscription has expired!" : "A Nextcloud előfizetése lejárt!",
    "Your server has no Nextcloud Subscription or your Subscription has expired" : "A szerverének nincs Nextcloud előfizetése vagy az előfizetés lejárt",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "A Nextcloud szervere nincs védve a Nextcloud vállalati előfizetés által.",
    "Update subscription key" : "Előfizetési kulcs frissítése",
    "Access Nextcloud portal" : "Belépés a Nextcloud portálra",
    "System information" : "Rendszer információ",
    "Generate system report" : "Rendszer jelentés készítése",
    "Enterprise subscription recommended" : "Vállalti előfizetés ajánlott",
    "No active enterprise subscription" : "Nincs aktív vállalati előfizetés",
    "Unsupported" : "Nem támogatott",
    "This Nextcloud server has no Enterprise Subscription." : "Ennek a Nextcloud szervernek nincs vállalati előfizetése.",
    "Advantages" : "Előnyök",
    "Get a quote" : "Árajánlat kérése",
    "More information" : "További információk",
    "Subscription benefits" : "Előfizetés előnyei",
    "Pricing" : "Árazás",
    "Commmunity support" : "Közösségi támogatás",
    "Forum" : "Fórum",
    "Nextcloud forum" : "Nextcloud fórum",
    "GitHub" : "GitHub",
    "Nextcloud at GitHub" : "Nextcloud a GitHub-on",
    "Chat" : "Csevegés",
    "Open chat" : "Csevegés indítása",
    "Subscription key" : "Előfizetési kulcs",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Ha van aktív Nextcloud előfizetése kérem adja meg az előfizetési kulcsot.",
    "Learn more about an enterprise subscription." : "Tudj meg többet a vállalati előfiztésről.",
    "Set subscription key" : "Előfizetési kulcs beállítása",
    "The subscription key was invalid." : "Előfizetési kulcs érvénytelen.",
    "The subscription key had an invalid format." : "Előfizetési kulcs érvénytelen formátumú.",
    "While fetching the subscription information an error happened." : "Hiba lépett fel az előfizetési információ letöltése közben.",
    "News" : "Hírek",
    "Follow us on Google+" : "Kövess Google+ -on",
    "Like our Facebook page" : "Lájkold a Facebook oldalunkat",
    "Follow us on Twitter" : "Kövess Twitteren",
    "Check out our blog" : "Nézd meg a blogunkat",
    "Subscribe to our newsletter" : "Iratkozz fel a hírlevelünkre"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/hu.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Hivatkozás:",
    "Password:" : "Jelszó:",
    "Generating system report failed." : "Hiba a rendszer jelentés készítése közben.",
    "Subscription notifications" : "Előfizetési értesítések",
    "Could not create folder \"System information\" to store generated report." : "Nem lehet \"Rendszer információ\" könyvtárat létre hozni a jelentések készítéséhez.",
    "Could not create file \"%s\" to store generated report." : "Nem lehet létrehozni a \"%s\" fájlt az előállított riport tárolásához.",
    "Could not share file \"%s\"." : "Nem lehet megosztani a \"%s\" fájlt.",
    "Nextcloud Subscription" : "Nextcloud előfizetés",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "A szerverének nincs Nextcloud előfizetése vagy az előfizetés lejárt.",
    "Your Nextcloud server subscription does not cover your number of users." : "A Nextcloud szerver előfizetése nem fedezi a felhasználói számát.",
    "Your Nextcloud Subscription has expired!" : "A Nextcloud előfizetése lejárt!",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "A Nextcloud szervere nincs védve a Nextcloud vállalati előfizetés által.",
    "Dear admin," : "Kedves Rendszergazda!",
    "Update subscription key" : "Előfizetési kulcs frissítése",
    "Access Nextcloud portal" : "Belépés a Nextcloud portálra",
    "System information" : "Rendszer információ",
    "Generate system report" : "Rendszer jelentés készítése",
    "Enterprise subscription recommended" : "Vállalti előfizetés ajánlott",
    "No active enterprise subscription" : "Nincs aktív vállalati előfizetés",
    "Unsupported" : "Nem támogatott",
    "This Nextcloud server has no Enterprise Subscription." : "Ennek a Nextcloud szervernek nincs vállalati előfizetése.",
    "Advantages" : "Előnyök",
    "Get a quote" : "Árajánlat kérése",
    "More information" : "További információk",
    "Subscription benefits" : "Előfizetés előnyei",
    "Pricing" : "Árazás",
    "Commmunity support" : "Közösségi támogatás",
    "Forum" : "Fórum",
    "Nextcloud forum" : "Nextcloud fórum",
    "GitHub" : "GitHub",
    "Nextcloud at GitHub" : "Nextcloud a GitHub-on",
    "Chat" : "Csevegés",
    "Open chat" : "Csevegés indítása",
    "Subscription key" : "Előfizetési kulcs",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Ha van aktív Nextcloud előfizetése kérem adja meg az előfizetési kulcsot.",
    "Learn more about an enterprise subscription." : "Tudj meg többet a vállalati előfiztésről.",
    "Set subscription key" : "Előfizetési kulcs beállítása",
    "The subscription key was invalid." : "Előfizetési kulcs érvénytelen.",
    "The subscription key had an invalid format." : "Előfizetési kulcs érvénytelen formátumú.",
    "While fetching the subscription information an error happened." : "Hiba lépett fel az előfizetési információ letöltése közben.",
    "News" : "Hírek",
    "Follow us on Google+" : "Kövess Google+ -on",
    "Like our Facebook page" : "Lájkold a Facebook oldalunkat",
    "Follow us on Twitter" : "Kövess Twitteren",
    "Check out our blog" : "Nézd meg a blogunkat",
    "Subscribe to our newsletter" : "Iratkozz fel a hírlevelünkre"
},
"nplurals=2; plural=(n != 1);");
